# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for
# license information.
#
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from .resource import Resource


class ContainerGroupDescription(Resource):
    """Describes a Container group.

    Variables are only populated by the server, and will be ignored when
    sending a request.

    :ivar id: Azure resource ID.
    :vartype id: str
    :ivar name: Azure resource name.
    :vartype name: str
    :ivar type: Azure resource type.
    :vartype type: str
    :param location: Resource location.
    :type location: str
    :param tags: Resource tags.
    :type tags: dict[str, str]
    :param containers: The containers in this container group.
    :type containers: list[~azure.mgmt.seabreeze.models.Container]
    :param image_registry_credentials: The image registry credentials by which
     the container group is created from.
    :type image_registry_credentials:
     list[~azure.mgmt.seabreeze.models.ImageRegistryCredential]
    :param restart_policy: - `always` Always restart
     . Possible values include: 'always'
    :type restart_policy: str or
     ~azure.mgmt.seabreeze.models.ContainerRestartPolicy
    :param ip_address: IP address for the container group.
    :type ip_address: ~azure.mgmt.seabreeze.models.IpAddress
    :param os_type: The base level OS type required by the containers in the
     group. Possible values include: 'Windows', 'Linux'
    :type os_type: str or ~azure.mgmt.seabreeze.models.OperatingSystemTypes
    :ivar state: The state of the container group. Only valid in response.
    :vartype state: str
    :param volumes: The volumes for this container group.
    :type volumes: list[~azure.mgmt.seabreeze.models.Volume]
    """

    _validation = {
        'id': {'readonly': True},
        'name': {'readonly': True},
        'type': {'readonly': True},
        'location': {'required': True},
        'containers': {'required': True},
        'os_type': {'required': True},
        'state': {'readonly': True},
    }

    _attribute_map = {
        'id': {'key': 'id', 'type': 'str'},
        'name': {'key': 'name', 'type': 'str'},
        'type': {'key': 'type', 'type': 'str'},
        'location': {'key': 'location', 'type': 'str'},
        'tags': {'key': 'tags', 'type': '{str}'},
        'containers': {'key': 'properties.containers', 'type': '[Container]'},
        'image_registry_credentials': {'key': 'properties.imageRegistryCredentials', 'type': '[ImageRegistryCredential]'},
        'restart_policy': {'key': 'properties.restartPolicy', 'type': 'str'},
        'ip_address': {'key': 'properties.ipAddress', 'type': 'IpAddress'},
        'os_type': {'key': 'properties.osType', 'type': 'str'},
        'state': {'key': 'properties.state', 'type': 'str'},
        'volumes': {'key': 'properties.volumes', 'type': '[Volume]'},
    }

    def __init__(self, location, containers, os_type, tags=None, image_registry_credentials=None, restart_policy=None, ip_address=None, volumes=None):
        super(ContainerGroupDescription, self).__init__(location=location, tags=tags)
        self.containers = containers
        self.image_registry_credentials = image_registry_credentials
        self.restart_policy = restart_policy
        self.ip_address = ip_address
        self.os_type = os_type
        self.state = None
        self.volumes = volumes
